@@ -634,6 +634,51 @@ class PrivmsgTestCase(ChannelPluginTestCase):
             finally:
                 self.irc.state.capabilities_ack.remove('message-tags')
 
+    def testClientTagReplyChannel(self):
+        self.irc.addCallback(self.First(self.irc))
+
+        try:
+            conf.supybot.protocols.irc.experimentalExtensions.setValue(True)
+            self.irc.state.capabilities_ack.add('message-tags')
+
+            # Reply in channel to channel message -> +draft/channel-context
+            # is absent
+            self.irc.feedMsg(ircmsgs.IrcMsg(
+                command='PRIVMSG', prefix=self.prefix,
+                args=('#foo', '%s: firstcmd' % self.nick),
+                server_tags={'msgid': 'foobar'}))
+            msg = self.irc.takeMsg()
+            self.assertEqual(msg, ircmsgs.IrcMsg(
+                command='PRIVMSG', args=('#foo', '%s: foo' % self.nick),
+                server_tags={'+draft/reply': 'foobar'}))
+
+            # Reply in private to channel message -> +draft/channel-context
+            # is present
+            with conf.supybot.reply.inPrivate.context(True):
+                self.irc.feedMsg(ircmsgs.IrcMsg(
+                    command='PRIVMSG', prefix=self.prefix,
+                    args=('#foo', '%s: firstcmd' % self.nick),
+                    server_tags={'msgid': 'foobar'}))
+                msg = self.irc.takeMsg()
+                self.assertEqual(msg, ircmsgs.IrcMsg(
+                    command='NOTICE', args=(self.nick, 'foo'),
+                    server_tags={'+draft/reply': 'foobar',
+                                 '+draft/channel-context': '#foo'}))
+
+            # Reply in private to private message -> +draft/channel-context
+            # is absent
+            self.irc.feedMsg(ircmsgs.IrcMsg(
+                command='PRIVMSG', prefix=self.prefix,
+                args=(self.nick, 'firstcmd'),
+                server_tags={'msgid': 'foobar'}))
+            msg = self.irc.takeMsg()
+            self.assertEqual(msg, ircmsgs.IrcMsg(
+                command='NOTICE', args=(self.nick, 'foo'),
+                server_tags={'+draft/reply': 'foobar'}))
+        finally:
+            conf.supybot.protocols.irc.experimentalExtensions.setValue(False)
+            self.irc.state.capabilities_ack.remove('message-tags')
+
     class TwoRepliesFirstAction(callbacks.Plugin):
         def testactionreply(self, irc, msg, args):
             irc.reply('foo', action=True)
@@ -930,16 +975,50 @@ class MultilinePrivmsgTestCase(ChannelPluginTestCase):
                 '-' + batch_name,)))
 
 
-class PluginRegexpTestCase(PluginTestCase):
+class PluginRegexpTestCase(ChannelPluginTestCase):
     plugins = ()
     class PCAR(callbacks.PluginRegexp):
+        regexps = ("test", "test2")
+
         def test(self, irc, msg, args):
             "<foo>"
             raise callbacks.ArgumentError
-    def testNoEscapingArgumentError(self):
+
+        def test2(self, irc, msg, args):
+            "<bar>"
+            irc.reply("hello")
+
+    def setUp(self):
+        super().setUp()
         self.irc.addCallback(self.PCAR(self.irc))
+
+    def testNoEscapingArgumentError(self):
         self.assertResponse('test', 'test <foo>')
 
+    def testReply(self):
+        self.irc.feedMsg(ircmsgs.IrcMsg(
+            prefix=self.prefix,
+            command='PRIVMSG',
+            args=(self.channel, 'foo <bar> baz')))
+        self.assertResponse(' ', 'hello')
+
+    def testIgnoreChathistory(self):
+        self.irc.feedMsg(ircmsgs.IrcMsg(
+            command='BATCH',
+            args=('+123', 'chathistory', self.channel)))
+
+        self.irc.feedMsg(ircmsgs.IrcMsg(
+            server_tags={'batch': '123'},
+            prefix=self.prefix,
+            command='PRIVMSG',
+            args=(self.channel, 'foo <bar> baz')))
+
+        self.irc.feedMsg(ircmsgs.IrcMsg(
+            command='BATCH',
+            args=('-123',)))
+
+        self.assertNoResponse(' ')
+
 class RichReplyMethodsTestCase(PluginTestCase):
     plugins = ('Config',)
     class NoCapability(callbacks.Plugin):
